"""
COPYRIGHT BENNY 2021

ALL RIGHTS RESERVED TO THE 
DEVELOPER OF THIS PROJECT.
"""

from .wrapper import Wrapper
from .utils import TokenInfo, Logger

class Account:
    def comingSoon():
        Logger.log(f"Account stuff coming soon.")
        return "coming soon"