"""
Selfcord
~~~~~~~~

A discord.py addon for selfbots in mind.  

© Benny 2021

"""

from .selfcord import *
from .channel2 import *
from .message2 import *
from .wrapper import *
from .utils import *
from .embed import *
from .user import *
from .userinfo import *
from .messages import *
from .account import *